
function ajusta_cara(file_in, name_out,tx,ty)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% function ajusta_cara(file_in, name_out,tx,ty)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%file_in ---> nombre de imagen de entrada, por ejemplo: Image001.bmp
%name out --> nombre de imagen procesada sin extension, por ejemplo: cara1_1
%tx  --> ancho de la imagen procesada, por ejemplo: 92
%ty --> alto de la imagen procesada, por ejemplo: 112

imagen=imread(file_in); %lectura de la imagen de entrada
figure(1)
imshow(imagen)  %visualizacion de la imagen
[cx,cy]=ginput(1)  %captura del centro de la imagen (NARIZ)
clear nueva
nueva=imagen((cy-ty):(cy+ty),(cx-tx):(cx+tx),:); %nueva imagen

file_out1=sprintf('%s.jpg',name_out) %nombre nueva imagen
file_out2=sprintf('%s.pgm',name_out) 
imwrite(nueva,file_out1) %guarda nueva imagen en color en formato jpg
imwrite(nueva,file_out2)%guarda nueva imagen en niveles de gris en formato pgm


figure(2)  %visualiza la nueva imagen en los dos formatos
imshow(file_out1)
figure(3)
imshow(file_out2)
